Index: trunk/src/inc/KMLNode.class.php
===================================================================
--- trunk/src/inc/KMLPlacemark.class.php	(revision 7725)
+++ trunk/src/inc/KMLNode.class.php	(revision 7765)
@@ -2,13 +2,13 @@
 /*
  * Project: NodeMap2.0
  * File: KMLPlacemark.class.php
  * Purpose: Placemark used in KMLFile
  */
 
-define('PLACEMARK_GREEN', 'greenArrowIcon');
-define('PLACEMARK_ORANGE', 'orangeArrowIcon');
-define('PLACEMARK_RED', 'redArrowIcon');
+define('NODE_GREEN', 'greenArrowIcon');
+define('NODE_ORANGE', 'orangeArrowIcon');
+define('NODE_RED', 'redArrowIcon');
 
-class KMLPlacemark {
+class KMLNode {
 	private $template = '
 		<Placemark id="%ID%">
@@ -41,9 +41,9 @@
 	private $longitude;				// Longitude of the node
 	private $latitude;				// Latitude of the node
-	private $style;					// Style of the placemark
+	private $style;					// Style of the node
 
 	/*
 	 * Function: __construct (constructor)
 	 * Description: Creating a new KMLFile
 	 * Parameters: -
 	 * Returns: -
@@ -61,5 +61,5 @@
 	/*
 	 * Function: setID
 	 * Description: Setting the ID of the placemark
 	 * Parameters: string $newID
 	 * Returns: -
@@ -71,5 +71,5 @@
 	/*
 	 * Function: setName
 	 * Description: Setting the name of the placemark
 	 * Parameters: string $newName
 	 * Returns: -
@@ -81,7 +81,7 @@
 	/*
 	 * Function: getName
 	 * Description: Getting the name of the placemark
 	 * Parameters: -
 	 * Returns: The name of the placemark
 	 */
 	function getName() {
@@ -91,5 +91,5 @@
 	/*
 	 * Function: setDescriptionLocation
 	 * Description: Setting the location description of the placemark
 	 * Parameters: string $newDescriptionLocation
 	 * Returns: -
@@ -101,5 +101,5 @@
 	/*
 	 * Function: setDescriptionStatus
 	 * Description: Setting the status description of the placemark
 	 * Parameters: string $newDescriptionStatus
 	 * Returns: -
@@ -111,5 +111,5 @@
 	/*
 	 * Function: setLongitude
 	 * Description: Setting the longitude of the placemark
 	 * Parameters: string $newLongitude
 	 * Returns: -
@@ -121,5 +121,5 @@
 	/*
 	 * Function: setLatitude
 	 * Description: Setting the latitude of the placemark
 	 * Parameters: string $newLatitude
 	 * Returns: -
@@ -131,5 +131,5 @@
 	/*
 	 * Function: setStyle
 	 * Description: Setting the style of the placemark
 	 * Parameters: string $newStyle
 	 * Returns: -
@@ -141,5 +141,5 @@
 	/*
 	 * Function: toString
 	 * Description: Converts the content of this placemark to a KML valid string
 	 * Parameters: -
 	 * Returns: KML valid string
@@ -2,13 +2,13 @@
 /*
  * Project: NodeMap2.0
- * File: KMLPlacemark.class.php
- * Purpose: Placemark used in KMLFile
+ * File: KMLNode.class.php
+ * Purpose: Node placemark used in KMLFile
  */
 
@@ -41,9 +41,9 @@
 	/*
 	 * Function: __construct (constructor)
-	 * Description: Creating a new KMLFile
+	 * Description: Creating a new KMLNode
 	 * Parameters: -
 	 * Returns: -
@@ -61,5 +61,5 @@
 	/*
 	 * Function: setID
-	 * Description: Setting the ID of the placemark
+	 * Description: Setting the ID of the node
 	 * Parameters: string $newID
 	 * Returns: -
@@ -71,5 +71,5 @@
 	/*
 	 * Function: setName
-	 * Description: Setting the name of the placemark
+	 * Description: Setting the name of the node
 	 * Parameters: string $newName
 	 * Returns: -
@@ -81,7 +81,7 @@
 	/*
 	 * Function: getName
-	 * Description: Getting the name of the placemark
+	 * Description: Getting the name of the node
 	 * Parameters: -
@@ -81,7 +81,7 @@
 	 * Parameters: -
-	 * Returns: The name of the placemark
+	 * Returns: The name of the node
 	 */
 	function getName() {
@@ -91,5 +91,5 @@
 	/*
 	 * Function: setDescriptionLocation
-	 * Description: Setting the location description of the placemark
+	 * Description: Setting the location description of the node
 	 * Parameters: string $newDescriptionLocation
 	 * Returns: -
@@ -101,5 +101,5 @@
 	/*
 	 * Function: setDescriptionStatus
-	 * Description: Setting the status description of the placemark
+	 * Description: Setting the status description of the node
 	 * Parameters: string $newDescriptionStatus
 	 * Returns: -
@@ -111,5 +111,5 @@
 	/*
 	 * Function: setLongitude
-	 * Description: Setting the longitude of the placemark
+	 * Description: Setting the longitude of the node
 	 * Parameters: string $newLongitude
 	 * Returns: -
@@ -121,5 +121,5 @@
 	/*
 	 * Function: setLatitude
-	 * Description: Setting the latitude of the placemark
+	 * Description: Setting the latitude of the node
 	 * Parameters: string $newLatitude
 	 * Returns: -
@@ -131,5 +131,5 @@
 	/*
 	 * Function: setStyle
-	 * Description: Setting the style of the placemark
+	 * Description: Setting the style of the node
 	 * Parameters: string $newStyle
 	 * Returns: -
@@ -141,5 +141,5 @@
 	/*
 	 * Function: toString
-	 * Description: Converts the content of this placemark to a KML valid string
+	 * Description: Converts the content of this node to a KML valid string
 	 * Parameters: -
 	 * Returns: KML valid string
